==> heartFEM-2.0.0.tar.gz: heartFEM-2.0.0/setup.py <==
from setuptools import setup
setup(
  name = 'heartFEM',         # How you named your package folder (MyLib)
  packages = ['heartFEM'],   # Chose the same as "name"
  version = '2.0.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Optimization of patient specific heart model with myocardium FEM and cardiovascular network Windkessel.',   # Give a short description about your library
  author = 'Wei Xuan Chan',                   # Type in your name
  author_email = 'w.x.chan1986@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/WeiXuanChan/heartFEM',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/WeiXuanChan/heartFEM/archive/v2.0.0.tar.gz',    
  keywords = ['medical', 'cardiac'],   # Keywords that define your package best
  install_requires=['numpy','matplotlib','scipy'],
  extras_require = {
        'fem analysis software':  ['fenics'],
        'circuit analysis':  ['ngspice'],
        'equation setup for heart':  ['lcleeHeart'],
        'data storage and processing':  ['vtk']
  },
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package    
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',    
    'License :: OSI Approved :: MIT License',   # Again, pick a license    
    'Programming Language :: Python :: 3.6',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
  ],
)

==> heartFEM-2.0.2.tar.gz: heartFEM-2.0.2/setup.py <==
from setuptools import setup
setup(
  name = 'heartFEM',         # How you named your package folder (MyLib)
  packages = ['heartFEM'],  
  include_package_data=True,   
  package_data={
        'ngspice_py':['*']
        },
  version = '2.0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Optimization of patient specific heart model with myocardium FEM and cardiovascular network Windkessel.',   # Give a short description about your library
  author = 'Wei Xuan Chan',                   # Type in your name
  author_email = 'w.x.chan1986@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/WeiXuanChan/heartFEM',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/WeiXuanChan/heartFEM/archive/v2.0.2.tar.gz',    
  keywords = ['medical', 'cardiac'],   # Keywords that define your package best
  install_requires=['numpy','matplotlib','scipy','heart_ngspice'],
  extras_require = {
        'fem analysis software':  ['fenics'],
        'circuit analysis':  ['ngspice'],
        'equation setup for heart':  ['lcleeHeart'],
        'data storage and processing':  ['vtk']
  },
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package    
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',    
    'License :: OSI Approved :: MIT License',   # Again, pick a license    
    'Programming Language :: Python :: 3.6',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
  ],
)
